@@ -18,10 +18,14 @@ export { webSocket };
 
 export type GitOauthProvider =
   | 'github'
+  | 'github_2'
   | 'gitlab'
   | 'bitbucket'
+  | 'bitbucket-server'
   | 'azure-devops';
 
+// The list of available Git providers for PAT
+// https://eclipse.dev/che/docs/stable/end-user-guide/using-a-git-provider-access-token/
 export type GitProvider =
   | 'github'
   | 'gitlab'
@@ -43,6 +47,21 @@ export type PersonalAccessToken = {
     }
 );
 
+export type SshKey = {
+  creationTimestamp?: Date;
+  name: string;
+  /**
+   * base64 encoded public key.
+   */
+  keyPub: string;
+};
+export type NewSshKey = Omit<SshKey, 'creationTimestamp'> & {
+  /**
+   * base64 encoded private key.
+   */
+  key: string;
+};
+
 export interface IPatch {
   op: string;
   path: string;
@@ -54,6 +73,19 @@ export interface IDockerConfig {
   resourceVersion?: string;
 }
 
+export interface IGitConfig {
+  resourceVersion?: string;
+  gitconfig: {
+    user: {
+      name: string;
+      email: string;
+    };
+    [section: string]: {
+      [key: string]: string;
+    };
+  };
+}
+
 export interface IWorkspacesDefaultPlugins {
   editor: string;
   plugins: string[];
@@ -80,9 +112,7 @@ export interface IServerConfig {
     disableInternalRegistry: boolean;
     externalDevfileRegistries: IExternalDevfileRegistry[];
   };
-  pluginRegistry: {
-    openVSXURL: string;
-  };
+  pluginRegistry: IPluginRegistry;
   timeouts: {
     inactivityTimeout: number;
     runTimeout: number;
@@ -96,6 +126,12 @@ export interface IServerConfig {
   dashboardLogo?: { base64data: string; mediatype: string };
 }
 
+export interface IPluginRegistry {
+  disableInternalRegistry?: boolean;
+  externalPluginRegistries?: { url: string }[];
+  openVSXURL?: string;
+}
+
 export interface IUserProfile {
   email: string;
   username: string;
