@@ -13,19 +13,24 @@
 import { V221DevfileComponents } from '@devfile/api';
 import { api } from '@eclipse-che/common';
 import * as k8s from '@kubernetes/client-node';
-import {
-  CustomResourceDefinition,
-  CustomResourceDefinitionList,
-  CustomResourceDefinitionSpecDevEnvironments,
-  IServerConfigApi,
-} from '../types';
-import { createError } from './helpers/createError';
-import { CustomObjectAPI, prepareCustomObjectAPI } from './helpers/prepareCustomObjectAPI';
-import { startTimeoutSeconds } from '../../constants/server-config';
-import { isLocalRun } from '../../localRun';
 import { readFileSync } from 'fs';
 import path from 'path';
 
+import { startTimeoutSeconds } from '@/constants/server-config';
+import { createError } from '@/devworkspaceClient/services/helpers/createError';
+import {
+  CustomObjectAPI,
+  prepareCustomObjectAPI,
+} from '@/devworkspaceClient/services/helpers/prepareCustomObjectAPI';
+import {
+  CheClusterCustomResource,
+  CheClusterCustomResourceSpecDevEnvironments,
+  CustomResourceDefinitionList,
+  IServerConfigApi,
+} from '@/devworkspaceClient/types';
+import { isLocalRun } from '@/localRun';
+import { logger } from '@/utils/logger';
+
 const CUSTOM_RESOURCE_DEFINITIONS_API_ERROR_LABEL = 'CUSTOM_RESOURCE_DEFINITIONS_API_ERROR';
 
 const GROUP = 'org.eclipse.che';
@@ -46,7 +51,7 @@ export class ServerConfigApiService implements IServerConfigApi {
     };
   }
 
-  async fetchCheCustomResource(): Promise<CustomResourceDefinition> {
+  async fetchCheCustomResource(): Promise<CheClusterCustomResource> {
     if (isLocalRun()) {
       return JSON.parse(
         readFileSync(path.join(__dirname, '../../../../run/.custom-resources')).toString(),
@@ -65,7 +70,7 @@ export class ServerConfigApiService implements IServerConfigApi {
     const customResourceDefinitionsList = body as CustomResourceDefinitionList;
 
     const cheCustomResource = customResourceDefinitionsList.items?.find(
-      (item: CustomResourceDefinition) =>
+      (item: CheClusterCustomResource) =>
         item.metadata?.name === this.env.NAME && item.metadata?.namespace === this.env.NAMESPACE,
     );
 
@@ -80,9 +85,9 @@ export class ServerConfigApiService implements IServerConfigApi {
   }
 
   getContainerBuild(
-    cheCustomResource: CustomResourceDefinition,
+    cheCustomResource: CheClusterCustomResource,
   ): Pick<
-    CustomResourceDefinitionSpecDevEnvironments,
+    CheClusterCustomResourceSpecDevEnvironments,
     'containerBuildConfiguration' | 'disableContainerBuildCapabilities'
   > {
     const { devEnvironments } = cheCustomResource.spec;
@@ -102,11 +107,11 @@ export class ServerConfigApiService implements IServerConfigApi {
     };
   }
 
-  getDefaultPlugins(cheCustomResource: CustomResourceDefinition): api.IWorkspacesDefaultPlugins[] {
+  getDefaultPlugins(cheCustomResource: CheClusterCustomResource): api.IWorkspacesDefaultPlugins[] {
     return cheCustomResource.spec.devEnvironments?.defaultPlugins || [];
   }
 
-  getDefaultDevfileRegistryUrl(cheCustomResource: CustomResourceDefinition): string {
+  getDefaultDevfileRegistryUrl(cheCustomResource: CheClusterCustomResource): string {
     let devfileRegistryURL = cheCustomResource.status?.devfileRegistryURL || '';
     if (devfileRegistryURL && !devfileRegistryURL.endsWith('/')) {
       devfileRegistryURL += '/';
@@ -115,18 +120,18 @@ export class ServerConfigApiService implements IServerConfigApi {
     return devfileRegistryURL;
   }
 
-  getDefaultPluginRegistryUrl(cheCustomResource: CustomResourceDefinition): string {
+  getDefaultPluginRegistryUrl(cheCustomResource: CheClusterCustomResource): string {
     return cheCustomResource.status?.pluginRegistryURL || '';
   }
 
-  getDefaultEditor(cheCustomResource: CustomResourceDefinition): string | undefined {
+  getDefaultEditor(cheCustomResource: CheClusterCustomResource): string | undefined {
     return (
       cheCustomResource.spec.devEnvironments?.defaultEditor ||
       process.env['CHE_DEFAULT_SPEC_DEVENVIRONMENTS_DEFAULTEDITOR']
     );
   }
 
-  getDefaultComponents(cheCustomResource: CustomResourceDefinition): V221DevfileComponents[] {
+  getDefaultComponents(cheCustomResource: CheClusterCustomResource): V221DevfileComponents[] {
     if (cheCustomResource.spec.devEnvironments?.defaultComponents) {
       return cheCustomResource.spec.devEnvironments.defaultComponents;
     }
@@ -135,8 +140,9 @@ export class ServerConfigApiService implements IServerConfigApi {
       try {
         return JSON.parse(process.env['CHE_DEFAULT_SPEC_DEVENVIRONMENTS_DEFAULTCOMPONENTS']);
       } catch (e) {
-        console.error(
-          `Unable to parse default components from environment variable CHE_DEFAULT_SPEC_DEVENVIRONMENTS_DEFAULTCOMPONENTS: ${e}`,
+        logger.error(
+          e,
+          `Unable to parse default components from environment variable CHE_DEFAULT_SPEC_DEVENVIRONMENTS_DEFAULTCOMPONENTS.`,
         );
       }
     }
@@ -144,32 +150,36 @@ export class ServerConfigApiService implements IServerConfigApi {
     return [];
   }
 
-  getOpenVSXURL(cheCustomResource: CustomResourceDefinition): string {
+  getPluginRegistry(cheCustomResource: CheClusterCustomResource): api.IPluginRegistry {
     // Undefined and empty value are treated in a different ways:
     //   - empty value forces to use embedded registry
     //   - undefined value means that the default value should be used
-    if (cheCustomResource.spec.components?.pluginRegistry?.openVSXURL !== undefined) {
-      return cheCustomResource.spec.components.pluginRegistry.openVSXURL;
+
+    const pluginRegistry = cheCustomResource.spec.components?.pluginRegistry || {};
+
+    if (pluginRegistry?.openVSXURL === undefined) {
+      pluginRegistry.openVSXURL =
+        process.env['CHE_DEFAULT_SPEC_COMPONENTS_PLUGINREGISTRY_OPENVSXURL'];
     }
 
-    return process.env['CHE_DEFAULT_SPEC_COMPONENTS_PLUGINREGISTRY_OPENVSXURL'] || '';
+    return pluginRegistry;
   }
 
-  getPvcStrategy(cheCustomResource: CustomResourceDefinition): string | undefined {
+  getPvcStrategy(cheCustomResource: CheClusterCustomResource): string | undefined {
     return cheCustomResource.spec.devEnvironments?.storage?.pvcStrategy;
   }
 
-  getInternalRegistryDisableStatus(cheCustomResource: CustomResourceDefinition): boolean {
+  getInternalRegistryDisableStatus(cheCustomResource: CheClusterCustomResource): boolean {
     return cheCustomResource.spec.components?.devfileRegistry?.disableInternalRegistry || false;
   }
 
   getExternalDevfileRegistries(
-    cheCustomResource: CustomResourceDefinition,
+    cheCustomResource: CheClusterCustomResource,
   ): api.IExternalDevfileRegistry[] {
     return cheCustomResource.spec.components?.devfileRegistry?.externalDevfileRegistries || [];
   }
 
-  getDashboardWarning(cheCustomResource: CustomResourceDefinition): string | undefined {
+  getDashboardWarning(cheCustomResource: CheClusterCustomResource): string | undefined {
     // Return the message if it is defined and the show flag is true
     if (cheCustomResource.spec.components?.dashboard?.headerMessage?.text) {
       return cheCustomResource.spec.components?.dashboard?.headerMessage?.show
@@ -183,7 +193,7 @@ export class ServerConfigApiService implements IServerConfigApi {
 
   // getRunningWorkspacesLimit return the maximum number of running workspaces.
   // See https://github.com/eclipse-che/che-operator/pull/1585 for details.
-  getRunningWorkspacesLimit(cheCustomResource: CustomResourceDefinition): number {
+  getRunningWorkspacesLimit(cheCustomResource: CheClusterCustomResource): number {
     return (
       cheCustomResource.spec.devEnvironments?.maxNumberOfRunningWorkspacesPerUser ||
       cheCustomResource.spec.components?.devWorkspace?.runningLimit ||
@@ -191,24 +201,24 @@ export class ServerConfigApiService implements IServerConfigApi {
     );
   }
 
-  getAllWorkspacesLimit(cheCustomResource: CustomResourceDefinition): number {
+  getAllWorkspacesLimit(cheCustomResource: CheClusterCustomResource): number {
     return cheCustomResource.spec.devEnvironments?.maxNumberOfWorkspacesPerUser || -1;
   }
 
-  getWorkspaceInactivityTimeout(cheCustomResource: CustomResourceDefinition): number {
+  getWorkspaceInactivityTimeout(cheCustomResource: CheClusterCustomResource): number {
     return cheCustomResource.spec.devEnvironments?.secondsOfInactivityBeforeIdling || -1;
   }
 
-  getWorkspaceRunTimeout(cheCustomResource: CustomResourceDefinition): number {
+  getWorkspaceRunTimeout(cheCustomResource: CheClusterCustomResource): number {
     return cheCustomResource.spec.devEnvironments?.secondsOfRunBeforeIdling || -1;
   }
 
-  getWorkspaceStartTimeout(cheCustomResource: CustomResourceDefinition): number {
+  getWorkspaceStartTimeout(cheCustomResource: CheClusterCustomResource): number {
     return cheCustomResource.spec.devEnvironments?.startTimeoutSeconds || startTimeoutSeconds;
   }
 
   getDashboardLogo(
-    cheCustomResource: CustomResourceDefinition,
+    cheCustomResource: CheClusterCustomResource,
   ): { base64data: string; mediatype: string } | undefined {
     return cheCustomResource.spec.components?.dashboard?.branding?.logo;
   }
