@@ -11,16 +11,14 @@
  */
 
 import { FastifyInstance } from 'fastify';
-import { baseApiPath } from '../../../constants/config';
-import { setup, teardown } from '../../../helpers/tests/appBuilder';
+
+import { baseApiPath } from '@/constants/config';
+import { setup, teardown } from '@/utils/appBuilder';
 
 jest.mock('../helpers/getDevWorkspaceClient.ts');
 jest.mock('../helpers/getToken.ts');
 jest.mock('../helpers/getServiceAccountToken.ts');
 
-// mute the outputs
-console.log = jest.fn();
-
 describe('Server Config Route', () => {
   let app: FastifyInstance;
   const pluginRegistryInternalURL = 'http://plugin-registry.internal';
