@@ -10,12 +10,13 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import { FastifyInstance } from 'fastify';
-import { baseApiPath } from '../../constants/config';
-import { getDevWorkspaceClient } from './helpers/getDevWorkspaceClient';
-import { getServiceAccountToken } from './helpers/getServiceAccountToken';
-import { getSchema } from '../../services/helpers';
 import { api } from '@eclipse-che/common';
+import { FastifyInstance } from 'fastify';
+
+import { baseApiPath } from '@/constants/config';
+import { getDevWorkspaceClient } from '@/routes/api/helpers/getDevWorkspaceClient';
+import { getServiceAccountToken } from '@/routes/api/helpers/getServiceAccountToken';
+import { getSchema } from '@/services/helpers';
 
 const tags = ['Server Config'];
 
@@ -38,7 +39,7 @@ export function registerServerConfigRoute(instance: FastifyInstance) {
       const inactivityTimeout = serverConfigApi.getWorkspaceInactivityTimeout(cheCustomResource);
       const runTimeout = serverConfigApi.getWorkspaceRunTimeout(cheCustomResource);
       const startTimeout = serverConfigApi.getWorkspaceStartTimeout(cheCustomResource);
-      const openVSXURL = serverConfigApi.getOpenVSXURL(cheCustomResource);
+      const pluginRegistry = serverConfigApi.getPluginRegistry(cheCustomResource);
       const pvcStrategy = serverConfigApi.getPvcStrategy(cheCustomResource);
       const pluginRegistryURL = serverConfigApi.getDefaultPluginRegistryUrl(cheCustomResource);
       const devfileRegistryURL = serverConfigApi.getDefaultDevfileRegistryUrl(cheCustomResource);
@@ -65,9 +66,7 @@ export function registerServerConfigRoute(instance: FastifyInstance) {
           disableInternalRegistry,
           externalDevfileRegistries,
         },
-        pluginRegistry: {
-          openVSXURL,
-        },
+        pluginRegistry,
         cheNamespace,
         pluginRegistryURL,
         pluginRegistryInternalURL,
