@@ -10,7 +10,6 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import React, { ErrorInfo, PropsWithChildren } from 'react';
 import {
   Alert,
   AlertActionLink,
@@ -21,14 +20,18 @@ import {
   TextContent,
   TextVariants,
 } from '@patternfly/react-core';
+import React, { ErrorInfo, PropsWithChildren } from 'react';
 import Pluralize from 'react-pluralize';
-import { DisposableCollection } from '../../services/helpers/disposable';
+
+import { DisposableCollection } from '@/services/helpers/disposable';
 
 export const STORAGE_KEY_RELOAD_NUMBER = 'UD:ErrorBoundary:reloaded';
 const RELOAD_TIMEOUT_SEC = 30;
 const RELOADS_FOR_EXTENDED_MESSAGE = 2;
 
-type Props = PropsWithChildren;
+type Props = PropsWithChildren & {
+  onError: (error?: string) => void;
+};
 type State = {
   hasError: boolean;
   error?: Error;
@@ -74,6 +77,7 @@ export class ErrorBoundary extends React.PureComponent<Props, State> {
     });
 
     if (this.testResourceNotFound(error)) {
+      this.props.onError(error.message);
       this.setState({
         shouldReload: true,
       });
