@@ -15,24 +15,29 @@ import { AlertVariant } from '@patternfly/react-core';
 import { isEqual } from 'lodash';
 import React from 'react';
 import { connect, ConnectedProps } from 'react-redux';
-import { WorkspaceParams } from '../../../../Routes/routes';
-import { findTargetWorkspace } from '../../../../services/helpers/factoryFlow/findTargetWorkspace';
-import { AlertItem, DevWorkspaceStatus, LoaderTab } from '../../../../services/helpers/types';
-import { Workspace } from '../../../../services/workspace-adapter';
-import { AppState } from '../../../../store';
-import { selectStartTimeout } from '../../../../store/ServerConfig/selectors';
-import * as WorkspaceStore from '../../../../store/Workspaces';
-import { selectAllWorkspaces } from '../../../../store/Workspaces/selectors';
-import { ProgressStep, ProgressStepProps, ProgressStepState } from '../../ProgressStep';
-import { ProgressStepTitle } from '../../StepTitle';
-import { TimeLimit } from '../../TimeLimit';
-import workspaceStatusIs from '../../workspaceStatusIs';
+
+import {
+  ProgressStep,
+  ProgressStepProps,
+  ProgressStepState,
+} from '@/components/WorkspaceProgress/ProgressStep';
 import {
   applyRestartDefaultLocation,
   applyRestartInSafeModeLocation,
   getStartParams,
   resetRestartInSafeModeLocation,
-} from './prepareRestart';
+} from '@/components/WorkspaceProgress/StartingSteps/StartWorkspace/prepareRestart';
+import { ProgressStepTitle } from '@/components/WorkspaceProgress/StepTitle';
+import { TimeLimit } from '@/components/WorkspaceProgress/TimeLimit';
+import workspaceStatusIs from '@/components/WorkspaceProgress/workspaceStatusIs';
+import { WorkspaceParams } from '@/Routes/routes';
+import { findTargetWorkspace } from '@/services/helpers/factoryFlow/findTargetWorkspace';
+import { AlertItem, DevWorkspaceStatus, LoaderTab } from '@/services/helpers/types';
+import { Workspace } from '@/services/workspace-adapter';
+import { AppState } from '@/store';
+import { selectStartTimeout } from '@/store/ServerConfig/selectors';
+import * as WorkspaceStore from '@/store/Workspaces';
+import { selectAllWorkspaces } from '@/store/Workspaces/selectors';
 
 export type Props = MappedProps &
   ProgressStepProps & {
