@@ -10,8 +10,7 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import React from 'react';
-import { Link } from 'react-router-dom';
+import common from '@eclipse-che/common';
 import {
   AlertVariant,
   Button,
@@ -20,25 +19,28 @@ import {
   Tab,
   Tabs,
 } from '@patternfly/react-core';
-import common from '@eclipse-che/common';
-import Head from '../../components/Head';
-import { WorkspaceDetailsTab } from '../../services/helpers/types';
-import Header from './Header';
-import ProgressIndicator from '../../components/Progress';
-import { HeaderActionSelect } from './Header/Actions';
-import { lazyInject } from '../../inversify.config';
-import { AppAlerts } from '../../services/alerts/appAlerts';
-import OverviewTab, { OverviewTab as Overview } from './OverviewTab';
-import DevfileEditorTab, { DevfileEditorTab as Editor } from './DevfileEditorTab';
-import DevworkspaceEditorTab from './DevworkspaceEditorTab';
-import { History, UnregisterCallback, Location } from 'history';
-import { Workspace } from '../../services/workspace-adapter';
-import UnsavedChangesModal from '../../components/UnsavedChangesModal';
-import { buildDetailsLocation } from '../../services/helpers/location';
-import WorkspaceEvents from '../../components/WorkspaceEvents';
+import { History, Location, UnregisterCallback } from 'history';
+import React from 'react';
+import { Link } from 'react-router-dom';
 
-import styles from './index.module.css';
-import WorkspaceLogs from '../../components/WorkspaceLogs';
+import Head from '@/components/Head';
+import ProgressIndicator from '@/components/Progress';
+import UnsavedChangesModal from '@/components/UnsavedChangesModal';
+import WorkspaceEvents from '@/components/WorkspaceEvents';
+import WorkspaceLogs from '@/components/WorkspaceLogs';
+import { lazyInject } from '@/inversify.config';
+import DevfileEditorTab, {
+  DevfileEditorTab as Editor,
+} from '@/pages/WorkspaceDetails/DevfileEditorTab';
+import DevworkspaceEditorTab from '@/pages/WorkspaceDetails/DevworkspaceEditorTab';
+import Header from '@/pages/WorkspaceDetails/Header';
+import { HeaderActionSelect } from '@/pages/WorkspaceDetails/Header/Actions';
+import styles from '@/pages/WorkspaceDetails/index.module.css';
+import OverviewTab, { OverviewTab as Overview } from '@/pages/WorkspaceDetails/OverviewTab';
+import { AppAlerts } from '@/services/alerts/appAlerts';
+import { buildDetailsLocation } from '@/services/helpers/location';
+import { WorkspaceDetailsTab } from '@/services/helpers/types';
+import { Workspace } from '@/services/workspace-adapter';
 
 export const SECTION_THEME = PageSectionVariants.light;
 
@@ -175,9 +177,7 @@ export class WorkspaceDetails extends React.PureComponent<Props, State> {
   }
 
   private handleDiscardChanges(pathname: string): void {
-    if (this.state.activeTabKey === WorkspaceDetailsTab.DEVFILE) {
-      this.editorTabPageRef.current?.cancelChanges();
-    } else if (this.state.activeTabKey === WorkspaceDetailsTab.OVERVIEW) {
+    if (this.state.activeTabKey === WorkspaceDetailsTab.OVERVIEW) {
       this.overviewTabPageRef.current?.cancelChanges();
     }
 
@@ -193,9 +193,7 @@ export class WorkspaceDetails extends React.PureComponent<Props, State> {
   }
 
   private hasUnsavedChanges(): boolean {
-    if (this.state.activeTabKey === WorkspaceDetailsTab.DEVFILE) {
-      return this.editorTabPageRef.current?.state.hasChanges === true;
-    } else if (this.state.activeTabKey === WorkspaceDetailsTab.OVERVIEW) {
+    if (this.state.activeTabKey === WorkspaceDetailsTab.OVERVIEW) {
       return this.overviewTabPageRef.current?.hasChanges === true;
     }
     return false;
@@ -246,12 +244,8 @@ export class WorkspaceDetails extends React.PureComponent<Props, State> {
             <Tab eventKey={WorkspaceDetailsTab.DEVFILE} title={WorkspaceDetailsTab.DEVFILE}>
               <ProgressIndicator isLoading={this.props.isLoading} />
               <DevfileEditorTab
-                ref={this.editorTabPageRef}
                 workspace={workspace}
-                isRunning={workspace.isRunning}
-                isReadonly={true}
-                onSave={workspace => this.handleOnSave(workspace)}
-                onDevWorkspaceWarning={() => this.handleRestartWarning()}
+                isActive={WorkspaceDetailsTab.DEVFILE === this.state.activeTabKey}
               />
             </Tab>
             <Tab
@@ -285,7 +279,6 @@ export class WorkspaceDetails extends React.PureComponent<Props, State> {
     try {
       await this.props.onSave(workspace);
       this.showAlert(AlertVariant.success, 'Workspace has been updated');
-      this.editorTabPageRef.current?.cancelChanges();
 
       const location = buildDetailsLocation(workspace, this.state.activeTabKey);
       this.props.history.replace(location);
