@@ -11,13 +11,15 @@
  */
 
 import mockAxios from 'axios';
+import { AnyAction } from 'redux';
 import { MockStoreEnhanced } from 'redux-mock-store';
 import { ThunkDispatch } from 'redux-thunk';
-import { FakeStoreBuilder } from '../../__mocks__/storeBuilder';
+
+import { AppState } from '@/store';
+import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
+import { AUTHORIZED } from '@/store/sanityCheckMiddleware';
+
 import * as devfileRegistriesStore from '..';
-import { AppState } from '../..';
-import { AnyAction } from 'redux';
-import { AUTHORIZED } from '../../sanityCheckMiddleware';
 
 // mute error outputs
 console.error = jest.fn();
@@ -58,6 +60,14 @@ describe('Devfile registries', () => {
       const actions = store.getActions();
 
       const expectedActions: devfileRegistriesStore.KnownAction[] = [
+        {
+          type: devfileRegistriesStore.Type.REQUEST_REGISTRY_METADATA,
+          check: AUTHORIZED,
+        },
+        {
+          type: devfileRegistriesStore.Type.REQUEST_REGISTRY_METADATA,
+          check: AUTHORIZED,
+        },
         {
           type: devfileRegistriesStore.Type.REQUEST_REGISTRY_METADATA,
           check: AUTHORIZED,
@@ -109,11 +119,21 @@ describe('Devfile registries', () => {
         store.dispatch(
           devfileRegistriesStore.actionCreators.requestRegistriesMetadata(locations, false),
         ),
-      ).rejects.toMatch('Failed to fetch devfiles metadata from registry');
+      ).rejects.toMatch(
+        'Failed to fetch devfiles metadata from registry URL: http://example.com/location3, reason: Unexpected error. Check DevTools console and network tabs for more information.',
+      );
 
       const actions = store.getActions();
 
       const expectedActions: devfileRegistriesStore.KnownAction[] = [
+        {
+          type: devfileRegistriesStore.Type.REQUEST_REGISTRY_METADATA,
+          check: AUTHORIZED,
+        },
+        {
+          type: devfileRegistriesStore.Type.REQUEST_REGISTRY_METADATA,
+          check: AUTHORIZED,
+        },
         {
           type: devfileRegistriesStore.Type.REQUEST_REGISTRY_METADATA,
           check: AUTHORIZED,
@@ -171,53 +191,6 @@ describe('Devfile registries', () => {
 
       expect(actions).toEqual(expectedActions);
     });
-
-    it('should create REQUEST_SCHEMA and RECEIVE_SCHEMA when fetching all devfile schemas', async () => {
-      const schemaV1 = getSchemaV1();
-      const schemaV200 = getSchemaV200();
-      const schemaV210 = getSchemaV210();
-      const schemaV220 = getSchemaV220();
-      const schemav221alpha = getSchemaV221Alpha();
-      (mockAxios.get as jest.Mock).mockResolvedValueOnce({
-        data: schemaV1,
-      });
-      (mockAxios.get as jest.Mock).mockResolvedValueOnce({
-        data: schemaV200,
-      });
-      (mockAxios.get as jest.Mock).mockResolvedValueOnce({
-        data: schemaV210,
-      });
-      (mockAxios.get as jest.Mock).mockResolvedValueOnce({
-        data: schemaV220,
-      });
-      (mockAxios.get as jest.Mock).mockResolvedValueOnce({
-        data: schemav221alpha,
-      });
-
-      const store = new FakeStoreBuilder().build() as MockStoreEnhanced<
-        AppState,
-        ThunkDispatch<AppState, undefined, devfileRegistriesStore.KnownAction>
-      >;
-
-      await store.dispatch(devfileRegistriesStore.actionCreators.requestJsonSchema());
-
-      const actions = store.getActions();
-
-      const expectedActions: devfileRegistriesStore.KnownAction[] = [
-        {
-          type: devfileRegistriesStore.Type.REQUEST_SCHEMA,
-          check: AUTHORIZED,
-        },
-        {
-          type: devfileRegistriesStore.Type.RECEIVE_SCHEMA,
-          schema: {
-            oneOf: expect.arrayContaining([schemaV200, schemaV210, schemaV220]),
-          },
-        },
-      ];
-
-      expect(actions).toEqual(expectedActions);
-    });
   });
 
   describe('reducer', () => {
@@ -233,7 +206,6 @@ describe('Devfile registries', () => {
         registries: {},
         devfiles: {},
         devWorkspaceResources: {},
-        schema: {},
         filter: '',
       };
 
@@ -246,7 +218,6 @@ describe('Devfile registries', () => {
         registries: {},
         devfiles: {},
         devWorkspaceResources: {},
-        schema: {},
         filter: '',
       };
       const incomingAction = {
@@ -259,7 +230,6 @@ describe('Devfile registries', () => {
         registries: {},
         devfiles: {},
         devWorkspaceResources: {},
-        schema: {},
         filter: '',
       };
       expect(newState).toEqual(expectedState);
@@ -271,7 +241,6 @@ describe('Devfile registries', () => {
         registries: {},
         devfiles: {},
         devWorkspaceResources: {},
-        schema: {},
         filter: '',
       };
       const incomingAction: devfileRegistriesStore.RequestRegistryMetadataAction = {
@@ -285,7 +254,6 @@ describe('Devfile registries', () => {
         registries: {},
         devfiles: {},
         devWorkspaceResources: {},
-        schema: {},
         filter: '',
       };
       expect(newState).toEqual(expectedState);
@@ -297,7 +265,6 @@ describe('Devfile registries', () => {
         registries: {},
         devfiles: {},
         devWorkspaceResources: {},
-        schema: {},
         filter: '',
       };
       const url = 'http://example.com/devfiles/registry';
@@ -316,7 +283,6 @@ describe('Devfile registries', () => {
         },
         devfiles: {},
         devWorkspaceResources: {},
-        schema: {},
         filter: '',
       };
       expect(newState).toEqual(expectedState);
@@ -328,7 +294,6 @@ describe('Devfile registries', () => {
         registries: {},
         devfiles: {},
         devWorkspaceResources: {},
-        schema: {},
         filter: '',
       };
       const url = 'http://example.com/devfiles/registry';
@@ -347,7 +312,6 @@ describe('Devfile registries', () => {
         },
         devfiles: {},
         devWorkspaceResources: {},
-        schema: {},
         filter: '',
       };
       expect(newState).toEqual(expectedState);
@@ -359,7 +323,6 @@ describe('Devfile registries', () => {
         registries: {},
         devfiles: {},
         devWorkspaceResources: {},
-        schema: {},
         filter: '',
       };
       const incomingAction: devfileRegistriesStore.RequestDevfileAction = {
@@ -373,7 +336,6 @@ describe('Devfile registries', () => {
         registries: {},
         devfiles: {},
         devWorkspaceResources: {},
-        schema: {},
         filter: '',
       };
       expect(newState).toEqual(expectedState);
@@ -385,7 +347,6 @@ describe('Devfile registries', () => {
         registries: {},
         devfiles: {},
         devWorkspaceResources: {},
-        schema: {},
         filter: '',
       };
       const url = 'http://example.com/devfile.yaml';
@@ -404,89 +365,6 @@ describe('Devfile registries', () => {
           [url]: { content },
         },
         devWorkspaceResources: {},
-        schema: {},
-        filter: '',
-      };
-      expect(newState).toEqual(expectedState);
-    });
-
-    it('should should handle REQUEST_SCHEMA', () => {
-      const initialState: devfileRegistriesStore.State = {
-        isLoading: false,
-        registries: {},
-        devfiles: {},
-        devWorkspaceResources: {},
-        schema: {},
-        filter: '',
-      };
-      const incomingAction: devfileRegistriesStore.RequestSchemaAction = {
-        type: devfileRegistriesStore.Type.REQUEST_SCHEMA,
-        check: AUTHORIZED,
-      };
-      const newState = devfileRegistriesStore.reducer(initialState, incomingAction);
-
-      const expectedState: devfileRegistriesStore.State = {
-        isLoading: true,
-        registries: {},
-        devfiles: {},
-        devWorkspaceResources: {},
-        schema: {},
-        filter: '',
-      };
-      expect(newState).toEqual(expectedState);
-    });
-
-    it('should should handle RECEIVE_SCHEMA', () => {
-      const initialState: devfileRegistriesStore.State = {
-        isLoading: true,
-        registries: {},
-        devfiles: {},
-        devWorkspaceResources: {},
-        schema: {},
-        filter: '',
-      };
-      const schema = getSchemaV1();
-      const incomingAction: devfileRegistriesStore.ReceiveSchemaAction = {
-        type: devfileRegistriesStore.Type.RECEIVE_SCHEMA,
-        schema,
-      };
-      const newState = devfileRegistriesStore.reducer(initialState, incomingAction);
-
-      const expectedState: devfileRegistriesStore.State = {
-        isLoading: false,
-        registries: {},
-        devfiles: {},
-        devWorkspaceResources: {},
-        schema: { schema },
-        filter: '',
-      };
-      expect(newState).toEqual(expectedState);
-    });
-
-    it('should should handle RECEIVE_SCHEMA_ERROR', () => {
-      const initialState: devfileRegistriesStore.State = {
-        isLoading: true,
-        registries: {},
-        devfiles: {},
-        devWorkspaceResources: {},
-        schema: {},
-        filter: '',
-      };
-      const error = 'error message';
-      const incomingAction: devfileRegistriesStore.ReceiveSchemaErrorAction = {
-        type: devfileRegistriesStore.Type.RECEIVE_SCHEMA_ERROR,
-        error,
-      };
-      const newState = devfileRegistriesStore.reducer(initialState, incomingAction);
-
-      const expectedState: devfileRegistriesStore.State = {
-        isLoading: false,
-        registries: {},
-        devfiles: {},
-        devWorkspaceResources: {},
-        schema: {
-          error,
-        },
         filter: '',
       };
       expect(newState).toEqual(expectedState);
@@ -525,102 +403,3 @@ function getMetadataV2(): che.DevfileMetaData[] {
     },
   ];
 }
-
-function getSchemaV1() {
-  return {
-    $schema: 'http://json-schema.org/draft-07/schema#',
-    type: 'object',
-    title: 'Devfile object',
-    description: 'This schema describes the structure of the devfile object',
-    definitions: {
-      attributes: {
-        type: 'object',
-        additionalProperties: {
-          type: 'string',
-        },
-      },
-      selector: {
-        type: 'object',
-        additionalProperties: {
-          type: 'string',
-        },
-      },
-    },
-    additionalProperties: false,
-    properties: {},
-  };
-}
-
-function getSchemaV200() {
-  return {
-    description:
-      'Devfile describes the structure of a cloud-native workspace and development environment.',
-    type: 'object',
-    title: 'Devfile schema - Version 2.0.0',
-    required: ['schemaVersion'],
-    properties: {
-      schemaVersion: {
-        description: 'Devfile schema version',
-        type: 'string',
-        pattern: '^2\\.0\\.0$',
-      },
-    },
-    additionalProperties: false,
-  };
-}
-
-function getSchemaV210() {
-  return {
-    description:
-      'Devfile describes the structure of a cloud-native devworkspace and development environment.',
-    type: 'object',
-    title: 'Devfile schema - Version 2.1.0',
-    required: ['schemaVersion'],
-    properties: {
-      schemaVersion: {
-        description: 'Devfile schema version',
-        type: 'string',
-        pattern: '^2\\.1\\.0$',
-      },
-    },
-    additionalProperties: false,
-  };
-}
-
-function getSchemaV220() {
-  return {
-    description:
-      'Devfile describes the structure of a cloud-native devworkspace and development environment.',
-    type: 'object',
-    title: 'Devfile schema - Version 2.2.0',
-    required: ['schemaVersion'],
-    properties: {
-      schemaVersion: {
-        description: 'Devfile schema version',
-        type: 'string',
-        pattern:
-          '^([2-9])\\.([0-9]+)\\.([0-9]+)(\\-[0-9a-z-]+(\\.[0-9a-z-]+)*)?(\\+[0-9A-Za-z-]+(\\.[0-9A-Za-z-]+)*)?$',
-      },
-    },
-    additionalProperties: false,
-  };
-}
-
-function getSchemaV221Alpha() {
-  return {
-    description:
-      'Devfile describes the structure of a cloud-native devworkspace and development environment.',
-    type: 'object',
-    title: 'Devfile schema - Version 2.2.1-alpha',
-    required: ['schemaVersion'],
-    properties: {
-      schemaVersion: {
-        description: 'Devfile schema version',
-        type: 'string',
-        pattern:
-          '^([2-9])\\.([0-9]+)\\.([0-9]+)(\\-[0-9a-z-]+(\\.[0-9a-z-]+)*)?(\\+[0-9A-Za-z-]+(\\.[0-9A-Za-z-]+)*)?$',
-      },
-    },
-    additionalProperties: false,
-  };
-}
