@@ -13,53 +13,52 @@
 import common, { api, ApplicationId } from '@eclipse-che/common';
 import { dump } from 'js-yaml';
 import { Action, Reducer } from 'redux';
-import { AppThunk } from '../..';
-import { container } from '../../../inversify.config';
-import { FactoryParams } from '../../../services/helpers/factoryFlow/buildFactoryParams';
-import {
-  injectKubeConfig,
-  podmanLogin,
-} from '../../../services/dashboard-backend-client/devWorkspaceApi';
-import { fetchResources } from '../../../services/dashboard-backend-client/devworkspaceResourcesApi';
-import { WebsocketClient } from '../../../services/dashboard-backend-client/websocketClient';
-import devfileApi, { isDevWorkspace } from '../../../services/devfileApi';
-import { devWorkspaceKind } from '../../../services/devfileApi/devWorkspace';
+
+import { container } from '@/inversify.config';
+import * as DwApi from '@/services/backend-client/devWorkspaceApi';
+import { injectKubeConfig, podmanLogin } from '@/services/backend-client/devWorkspaceApi';
+import { fetchResources } from '@/services/backend-client/devworkspaceResourcesApi';
+import * as DwtApi from '@/services/backend-client/devWorkspaceTemplateApi';
+import { WebsocketClient } from '@/services/backend-client/websocketClient';
+import devfileApi, { isDevWorkspace } from '@/services/devfileApi';
+import { devWorkspaceKind } from '@/services/devfileApi/devWorkspace';
 import {
   DEVWORKSPACE_CHE_EDITOR,
   DEVWORKSPACE_UPDATING_TIMESTAMP_ANNOTATION,
-} from '../../../services/devfileApi/devWorkspace/metadata';
-import { getDefer, IDeferred } from '../../../services/helpers/deferred';
-import { delay } from '../../../services/helpers/delay';
-import { DisposableCollection } from '../../../services/helpers/disposable';
-import { getNewerResourceVersion } from '../../../services/helpers/resourceVersion';
-import { DevWorkspaceStatus } from '../../../services/helpers/types';
-import OAuthService, { isOAuthResponse } from '../../../services/oauth';
-import { loadResourcesContent } from '../../../services/registry/resources';
-import { WorkspaceAdapter } from '../../../services/workspace-adapter';
+} from '@/services/devfileApi/devWorkspace/metadata';
+import { getDefer, IDeferred } from '@/services/helpers/deferred';
+import { delay } from '@/services/helpers/delay';
+import { DisposableCollection } from '@/services/helpers/disposable';
+import { FactoryParams } from '@/services/helpers/factoryFlow/buildFactoryParams';
+import { getNewerResourceVersion } from '@/services/helpers/resourceVersion';
+import { DevWorkspaceStatus } from '@/services/helpers/types';
+import OAuthService, { isOAuthResponse } from '@/services/oauth';
+import { loadResourcesContent } from '@/services/registry/resources';
+import { WorkspaceAdapter } from '@/services/workspace-adapter';
 import {
-  DevWorkspaceClient,
-  DEVWORKSPACE_NEXT_START_ANNOTATION,
   COMPONENT_UPDATE_POLICY,
+  DEVWORKSPACE_NEXT_START_ANNOTATION,
+  DevWorkspaceClient,
   REGISTRY_URL,
-} from '../../../services/workspace-client/devworkspace/devWorkspaceClient';
-import { getCustomEditor } from '../../../services/workspace-client/helpers';
-import { selectApplications } from '../../ClusterInfo/selectors';
-import { getEditor } from '../../DevfileRegistries/getEditor';
-import { createObject } from '../../helpers';
-import { selectDefaultNamespace } from '../../InfrastructureNamespaces/selectors';
-import { AUTHORIZED, SanityCheckAction } from '../../sanityCheckMiddleware';
-import * as DwServerConfigStore from '../../ServerConfig';
+} from '@/services/workspace-client/devworkspace/devWorkspaceClient';
+import { getCustomEditor } from '@/services/workspace-client/helpers';
+import { AppThunk } from '@/store';
+import { selectApplications } from '@/store/ClusterInfo/selectors';
+import { getEditor } from '@/store/DevfileRegistries/getEditor';
+import { selectDefaultDevfile } from '@/store/DevfileRegistries/selectors';
+import { createObject } from '@/store/helpers';
+import { selectDefaultNamespace } from '@/store/InfrastructureNamespaces/selectors';
+import { selectDefaultEditor } from '@/store/Plugins/devWorkspacePlugins/selectors';
+import { selectAsyncIsAuthorized, selectSanityCheckError } from '@/store/SanityCheck/selectors';
+import { AUTHORIZED, SanityCheckAction } from '@/store/sanityCheckMiddleware';
+import * as DwServerConfigStore from '@/store/ServerConfig';
 import {
   selectOpenVSXUrl,
   selectPluginRegistryInternalUrl,
   selectPluginRegistryUrl,
-} from '../../ServerConfig/selectors';
-import { checkRunningWorkspacesLimit } from './checkRunningWorkspacesLimit';
-import { selectDevWorkspacesResourceVersion } from './selectors';
-import * as DwtApi from '../../../services/dashboard-backend-client/devWorkspaceTemplateApi';
-import { selectDefaultDevfile } from '../../DevfileRegistries/selectors';
-import * as DwApi from '../../../services/dashboard-backend-client/devWorkspaceApi';
-import { selectDefaultEditor } from '../../Plugins/devWorkspacePlugins/selectors';
+} from '@/store/ServerConfig/selectors';
+import { checkRunningWorkspacesLimit } from '@/store/Workspaces/devWorkspaces/checkRunningWorkspacesLimit';
+import { selectDevWorkspacesResourceVersion } from '@/store/Workspaces/devWorkspaces/selectors';
 
 export const onStatusChangeCallbacks = new Map<string, (status: string) => void>();
 
@@ -195,9 +194,12 @@ export const actionCreators: ActionCreators = {
   requestWorkspaces:
     (): AppThunk<KnownAction, Promise<void>> =>
     async (dispatch, getState): Promise<void> => {
-      await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
-
       try {
+        await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
+        if (!(await selectAsyncIsAuthorized(getState()))) {
+          const error = selectSanityCheckError(getState());
+          throw new Error(error);
+        }
         const defaultKubernetesNamespace = selectDefaultNamespace(getState());
         const defaultNamespace = defaultKubernetesNamespace.name;
         const { workspaces, resourceVersion } = defaultNamespace
@@ -216,7 +218,6 @@ export const actionCreators: ActionCreators = {
           type: Type.UPDATE_STARTED_WORKSPACES,
           workspaces,
         });
-
         const promises = workspaces
           .filter(
             workspace =>
@@ -241,10 +242,13 @@ export const actionCreators: ActionCreators = {
 
   requestWorkspace:
     (workspace: devfileApi.DevWorkspace): AppThunk<KnownAction, Promise<void>> =>
-    async (dispatch): Promise<void> => {
-      await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
-
+    async (dispatch, getState): Promise<void> => {
       try {
+        await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
+        if (!(await selectAsyncIsAuthorized(getState()))) {
+          const error = selectSanityCheckError(getState());
+          throw new Error(error);
+        }
         const namespace = workspace.metadata.namespace;
         const name = workspace.metadata.name;
         const update = await getDevWorkspaceClient().getWorkspaceByName(namespace, name);
@@ -288,9 +292,13 @@ export const actionCreators: ActionCreators = {
         console.warn(`Workspace ${_workspace.metadata.name} already started`);
         return;
       }
-      await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
       try {
         await OAuthService.refreshTokenIfNeeded(workspace);
+        await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
+        if (!(await selectAsyncIsAuthorized(getState()))) {
+          const error = selectSanityCheckError(getState());
+          throw new Error(error);
+        }
         checkRunningWorkspacesLimit(getState());
 
         if (workspace.metadata.annotations?.[DEVWORKSPACE_NEXT_START_ANNOTATION]) {
@@ -438,8 +446,13 @@ export const actionCreators: ActionCreators = {
 
   terminateWorkspace:
     (workspace: devfileApi.DevWorkspace): AppThunk<KnownAction, Promise<void>> =>
-    async (dispatch): Promise<void> => {
+    async (dispatch, getState): Promise<void> => {
       try {
+        await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
+        if (!(await selectAsyncIsAuthorized(getState()))) {
+          const error = selectSanityCheckError(getState());
+          throw new Error(error);
+        }
         const namespace = workspace.metadata.namespace;
         const name = workspace.metadata.name;
         await getDevWorkspaceClient().delete(namespace, name);
@@ -464,10 +477,13 @@ export const actionCreators: ActionCreators = {
 
   updateWorkspaceAnnotation:
     (workspace: devfileApi.DevWorkspace): AppThunk<KnownAction, Promise<void>> =>
-    async (dispatch): Promise<void> => {
-      await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
-
+    async (dispatch, getState): Promise<void> => {
       try {
+        await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
+        if (!(await selectAsyncIsAuthorized(getState()))) {
+          const error = selectSanityCheckError(getState());
+          throw new Error(error);
+        }
         const updated = await getDevWorkspaceClient().updateAnnotation(workspace);
         dispatch({
           type: Type.UPDATE_DEVWORKSPACE,
@@ -487,10 +503,13 @@ export const actionCreators: ActionCreators = {
 
   updateWorkspace:
     (workspace: devfileApi.DevWorkspace): AppThunk<KnownAction, Promise<void>> =>
-    async (dispatch): Promise<void> => {
-      await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
-
+    async (dispatch, getState): Promise<void> => {
       try {
+        await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
+        if (!(await selectAsyncIsAuthorized(getState()))) {
+          const error = selectSanityCheckError(getState());
+          throw new Error(error);
+        }
         const updated = await getDevWorkspaceClient().update(workspace);
         dispatch({
           type: Type.UPDATE_DEVWORKSPACE,
@@ -516,21 +535,23 @@ export const actionCreators: ActionCreators = {
     ): AppThunk<KnownAction, Promise<void>> =>
     async (dispatch, getState): Promise<void> => {
       const state = getState();
-
-      await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
-
       const defaultKubernetesNamespace = selectDefaultNamespace(state);
       const openVSXUrl = selectOpenVSXUrl(state);
       const pluginRegistryUrl = selectPluginRegistryUrl(state);
       const pluginRegistryInternalUrl = selectPluginRegistryInternalUrl(state);
-      const cheEditor = editorId ? editorId : selectDefaultEditor(state);
       const defaultNamespace = defaultKubernetesNamespace.name;
+
       try {
+        await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
+        if (!(await selectAsyncIsAuthorized(getState()))) {
+          const error = selectSanityCheckError(getState());
+          throw new Error(error);
+        }
         /* create a new DevWorkspace */
         const createResp = await getDevWorkspaceClient().createDevWorkspace(
           defaultNamespace,
           devWorkspaceResource,
-          cheEditor,
+          editorId,
         );
 
         if (createResp.headers.warning) {
@@ -596,9 +617,6 @@ export const actionCreators: ActionCreators = {
     (workspace: devfileApi.DevWorkspace): AppThunk<KnownAction, Promise<void>> =>
     async (dispatch, getState): Promise<void> => {
       const state = getState();
-
-      await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
-
       const defaultsDevfile = selectDefaultDevfile(state);
       if (!defaultsDevfile) {
         throw new Error('Cannot define default devfile');
@@ -620,6 +638,11 @@ export const actionCreators: ActionCreators = {
       let devWorkspaceTemplateResource: devfileApi.DevWorkspaceTemplate;
 
       try {
+        await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
+        if (!(await selectAsyncIsAuthorized(getState()))) {
+          const error = selectSanityCheckError(getState());
+          throw new Error(error);
+        }
         const response = await getEditor(defaultsEditor, dispatch, getState, pluginRegistryUrl);
         if (response.content) {
           editorContent = response.content;
@@ -793,10 +816,7 @@ export const actionCreators: ActionCreators = {
     ): AppThunk<KnownAction, Promise<void>> =>
     async (dispatch, getState): Promise<void> => {
       const state = getState();
-
-      await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
-
-      const pluginRegistryUrl = state.dwServerConfig.config.pluginRegistryURL;
+      const pluginRegistryUrl = selectPluginRegistryUrl(state);
       let devWorkspaceResource: devfileApi.DevWorkspace;
       let devWorkspaceTemplateResource: devfileApi.DevWorkspaceTemplate;
       let editorContent: string | undefined;
@@ -843,6 +863,11 @@ export const actionCreators: ActionCreators = {
       }
 
       try {
+        await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
+        if (!(await selectAsyncIsAuthorized(getState()))) {
+          const error = selectSanityCheckError(getState());
+          throw new Error(error);
+        }
         const resourcesContent = await fetchResources({
           pluginRegistryUrl,
           devfileContent: dump(devfile),
@@ -1016,23 +1041,23 @@ export const reducer: Reducer<State> = (
   const action = incomingAction as KnownAction;
   switch (action.type) {
     case Type.REQUEST_DEVWORKSPACE:
-      return createObject(state, {
+      return createObject<State>(state, {
         isLoading: true,
         error: undefined,
       });
     case Type.RECEIVE_DEVWORKSPACE:
-      return createObject(state, {
+      return createObject<State>(state, {
         isLoading: false,
         workspaces: action.workspaces,
         resourceVersion: getNewerResourceVersion(action.resourceVersion, state.resourceVersion),
       });
     case Type.RECEIVE_DEVWORKSPACE_ERROR:
-      return createObject(state, {
+      return createObject<State>(state, {
         isLoading: false,
         error: action.error,
       });
     case Type.UPDATE_DEVWORKSPACE:
-      return createObject(state, {
+      return createObject<State>(state, {
         isLoading: false,
         workspaces: state.workspaces.map(workspace =>
           WorkspaceAdapter.getUID(workspace) === WorkspaceAdapter.getUID(action.workspace)
@@ -1045,7 +1070,7 @@ export const reducer: Reducer<State> = (
         ),
       });
     case Type.ADD_DEVWORKSPACE:
-      return createObject(state, {
+      return createObject<State>(state, {
         isLoading: false,
         workspaces: state.workspaces
           .filter(
@@ -1059,7 +1084,7 @@ export const reducer: Reducer<State> = (
         ),
       });
     case Type.TERMINATE_DEVWORKSPACE:
-      return createObject(state, {
+      return createObject<State>(state, {
         isLoading: false,
         workspaces: state.workspaces.map(workspace => {
           if (WorkspaceAdapter.getUID(workspace) === action.workspaceUID) {
@@ -1075,7 +1100,7 @@ export const reducer: Reducer<State> = (
         }),
       });
     case Type.DELETE_DEVWORKSPACE:
-      return createObject(state, {
+      return createObject<State>(state, {
         isLoading: false,
         workspaces: state.workspaces.filter(
           workspace =>
@@ -1087,7 +1112,7 @@ export const reducer: Reducer<State> = (
         ),
       });
     case Type.UPDATE_STARTED_WORKSPACES:
-      return createObject(state, {
+      return createObject<State>(state, {
         startedWorkspaces: action.workspaces.reduce((acc, workspace) => {
           if (workspace.spec.started === false) {
             delete acc[WorkspaceAdapter.getUID(workspace)];
@@ -1110,7 +1135,7 @@ export const reducer: Reducer<State> = (
         }, state.startedWorkspaces),
       });
     case Type.UPDATE_WARNING:
-      return createObject(state, {
+      return createObject<State>(state, {
         warnings: {
           [WorkspaceAdapter.getUID(action.workspace)]: action.warning,
         },
